@@ -1,10 +1,7 @@
-from __future__ import unicode_literals
-
-import cachetools
-
+import pykka
 from mopidy import backend, httpclient
 
-import pykka
+import cachetools
 
 from . import Extension
 from .client import InternetArchiveClient
@@ -26,18 +23,18 @@ class InternetArchiveBackend(pykka.ThreadingActor, backend.Backend):
     uri_schemes = [Extension.ext_name]
 
     def __init__(self, config, audio):
-        super(InternetArchiveBackend, self).__init__()
+        super().__init__()
         ext_config = config[Extension.ext_name]
 
         self.client = client = InternetArchiveClient(
-            ext_config['base_url'],
-            retries=ext_config['retries'],
-            timeout=ext_config['timeout']
+            ext_config["base_url"],
+            retries=ext_config["retries"],
+            timeout=ext_config["timeout"],
         )
-        product = '%s/%s' % (Extension.dist_name, Extension.version)
+        product = f"{Extension.dist_name}/{Extension.version}"
         client.useragent = httpclient.format_user_agent(product)
-        proxy = httpclient.format_proxy(config['proxy'])
-        client.proxies.update({'http': proxy, 'https': proxy})
+        proxy = httpclient.format_proxy(config["proxy"])
+        client.proxies.update({"http": proxy, "https": proxy})
         client.cache = _cache(**ext_config)
 
         self.library = InternetArchiveLibraryProvider(ext_config, self)
